# frozen_string_literal: true

module ActionPush
  module Ios
    # @refs https://developer.apple.com/library/archive/documentation/NetworkingInternet/Conceptual/RemoteNotificationsPG/PayloadKeyReference.html#//apple_ref/doc/uid/TP40008194-CH17-SW5
    class Message < Provider::Base
      # [Integer]
      # Include this key when you want the system to modify the badge of your app icon.
      # If this key is not included in the dictionary, the badge is not changed.
      # To remove the badge, set the value of this key to 0.
      attr_accessor :badge

      # [String]
      # Include this key when you want the system to play a sound.
      # The value of this key is the name of a sound file in your app’s main bundle or in the Library/Sounds
      attr_accessor :sound

      # [Integer]
      # Include this key with a value of 1 to configure a background update notification.
      # When this key is present, the system wakes up your app in the background and delivers the
      # notification to its app delegate
      attr_accessor :content_available

      # [String]
      # Provide this key with a string value that represents the notification’s type.
      # This value corresponds to the value in the identifier
      attr_accessor :category

      # [String]
      # Provide this key with a string value that represents the app-specific identifier
      # for grouping notifications
      attr_accessor :thread_id

      def alert=(alert)
        unless alert.is_a?(Alert)
          raise ArgumentError, "alert should be an instance of #{Alert}, got: <#{alert.class}>"
        end

        @alert = alert
      end

      def alert
        @alert ||= Alert.new
        block_given? ? yield(@alert) : @alert
      end

      def title=(value)
        alert.title = value
      end

      def body=(value)
        alert.body = value
      end

      def title
        alert.title
      end

      def body
        alert.body
      end
    end
  end
end
